@@ -1,9 +1,9 @@
-/** \file document.h
- * \brief API for working with documents
+/** @file document.h
+ * @brief API for working with documents
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2006,2007,2009,2010 Olly Betts
+ * Copyright 2002,2003,2004,2006,2007,2009,2010,2011,2012,2013,2014 Olly Betts
  * Copyright 2009 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -25,9 +25,14 @@
 #ifndef XAPIAN_INCLUDED_DOCUMENT_H
 #define XAPIAN_INCLUDED_DOCUMENT_H
 
+#if !defined XAPIAN_IN_XAPIAN_H && !defined XAPIAN_LIB_BUILD
+# error "Never use <xapian/document.h> directly; include <xapian.h> instead."
+#endif
+
 #include <string>
 
-#include <xapian/base.h>
+#include <xapian/attributes.h>
+#include <xapian/intrusive_ptr.h>
 #include <xapian/types.h>
 #include <xapian/termiterator.h>
 #include <xapian/valueiterator.h>
@@ -57,7 +62,7 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
     public:
 	class Internal;
 	/// @private @internal Reference counted internals.
-	Xapian::Internal::RefCntPtr<Internal> internal;
+	Xapian::Internal::intrusive_ptr<Internal> internal;
 
 	/** @private @internal Constructor is only used by internal classes.
 	 *
@@ -67,11 +72,15 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
 
 	/** Copying is allowed.  The internals are reference counted, so
 	 *  copying is cheap.
+	 *
+	 *  @param other	The object to copy.
 	 */
 	Document(const Document &other);
 
 	/** Assignment is allowed.  The internals are reference counted,
 	 *  so assignment is cheap.
+	 *
+	 *  @param other	The object to copy.
 	 */
 	void operator=(const Document &other);
 
@@ -86,32 +95,44 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
 	 *  Returns an empty string if no value with the given number is present
 	 *  in the document.
 	 *
-	 *  @param valueno The number of the value.
+	 *  @param slot The number of the value.
 	 */
-	std::string get_value(Xapian::valueno valueno) const;
+	std::string get_value(Xapian::valueno slot) const;
 
 	/** Add a new value.
 	 *
 	 *  The new value will replace any existing value with the same number
 	 *  (or if the new value is empty, it will remove any existing value
 	 *  with the same number).
+	 *
+	 *  @param slot		The value slot to add the value in.
+	 *  @param value	The value to set.
 	 */
-	void add_value(Xapian::valueno valueno, const std::string &value);
+	void add_value(Xapian::valueno slot, const std::string &value);
 
 	/// Remove any value with the given number.
-	void remove_value(Xapian::valueno valueno);
+	void remove_value(Xapian::valueno slot);
 
 	/// Remove all values associated with the document.
 	void clear_values();
 
 	/** Get data stored in the document.
-	 *  This is a potentially expensive operation, and shouldn't normally
-	 *  be used in a match decider functor.  Put data for use by match
-	 *  deciders in a value instead.
+	 *
+	 *  This is potentially a relatively expensive operation, and shouldn't
+	 *  normally be used during the match (e.g. in a PostingSource or match
+	 *  decider functor.  Put data for use by match deciders in a value
+	 *  instead.
 	 */
 	std::string get_data() const;
 
-	/// Set data stored in the document.
+	/** Set data stored in the document.
+	 *
+	 *  Xapian treats the data as an opaque blob.  It may try to compress
+	 *  it, but other than that it will just store it and return it when
+	 *  requested.
+	 *
+	 *  @param data	The data to store.
+	 */
 	void set_data(const std::string &data);
 
 	/** Add an occurrence of a term at a particular position.
@@ -205,8 +226,8 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
 	TermIterator termlist_begin() const;
 
 	/// Equivalent end iterator for termlist_begin().
-	TermIterator termlist_end() const {
-	    return TermIterator(NULL);
+	TermIterator XAPIAN_NOTHROW(termlist_end() const) {
+	    return TermIterator();
 	}
 
 	/// Count the values in this document.
@@ -216,8 +237,8 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
 	ValueIterator values_begin() const;
 
 	/// Equivalent end iterator for values_begin().
-	ValueIteratorEnd_ values_end() const {
-	    return ValueIteratorEnd_();
+	ValueIterator XAPIAN_NOTHROW(values_end() const) {
+	    return ValueIterator();
 	}
 
 	/** Get the document id which is associated with this document (if any).
@@ -244,7 +265,7 @@ class XAPIAN_VISIBILITY_DEFAULT Document {
 
 	/** Unserialise a document from a string produced by serialise().
 	 */
-	static Document unserialise(const std::string &s);
+	static Document unserialise(const std::string &serialised);
 
 	/// Return a string describing this object.
 	std::string get_description() const;
